@@ -328,15 +328,11 @@ audio_view_media_get_metadata (GstMediaInfoStream *info)
 		GstPropsEntry *entry = (GstPropsEntry *) p->data;
 		const gchar *name;
 		const gchar *val;
-		GstPropsType type;
 
 		name = gst_props_entry_get_name (entry);
-		type = gst_props_entry_get_type (entry);
-		if (g_ascii_strncasecmp (name, "artist", 6) == 0 &&
-		    type == GST_PROPS_STRING_TYPE)
+		if (g_ascii_strncasecmp (name, "artist", 6) == 0)
 			artist = g_list_append (artist, entry);
-		if (g_ascii_strncasecmp (name, "title", 6) == 0 &&
-		    type == GST_PROPS_STRING_TYPE)
+		if (g_ascii_strncasecmp (name, "title", 6) == 0)
 			title = g_list_append (title, entry);
 		p = g_list_next (p);
 	}
@@ -360,8 +356,7 @@ audio_view_media_get_metadata (GstMediaInfoStream *info)
 }
 
 /* set next track to play
- * return FALSE if this is the last track or if the next track is not
- * playable */
+ * return FALSE if this is the last track */
 static gboolean
 audio_view_play_next (AudioView *view)
 {
@@ -371,7 +366,6 @@ audio_view_play_next (AudioView *view)
 	GtkTreeIter iter;
 	GtkTreePath *path;
 	GstMediaInfoStream *info;
-	gchar *message;
 
 	g_assert (IS_AUDIO_PLAY (play));
 	NM_DEBUG("play_next: start\n");
@@ -397,24 +391,10 @@ audio_view_play_next (AudioView *view)
 				    AUDIO_INFO_COLUMN, &info,
 				    -1);
 		NM_DEBUG("play_next: track to play is %s\n", info->path);
-
-	if (!audio_view_is_playable (info->path))
-        {
-		NM_DEBUG("play_next: %s is not playable\n", info->path);
-		return FALSE;
 	}
 	audio_view_set_playing (view, info, path);
-		audio_view_set_playing (view, info, path);
-		gtk_tree_path_free (path);
-		return TRUE;
-	}
-	else
-	{
-		message = g_strdup_printf (_("Make a selection first !"));
-		gtk_label_set_text (GTK_LABEL (view->status), message);
-		g_free (message);
-		return FALSE;
-	}
+	gtk_tree_path_free (path);
+	return TRUE;
 }
 
 /* timeout for scanner */
@@ -614,7 +594,6 @@ prev_activate (GtkButton *prev_button, AudioView *view)
 	GtkTreeIter iter;
 	GtkTreePath *path;
 	GstMediaInfoStream *info;
-	gchar *message;
 
 	play = view->audio_play;
 	g_assert (IS_AUDIO_PLAY (play));
@@ -632,15 +611,8 @@ prev_activate (GtkButton *prev_button, AudioView *view)
 		gtk_tree_model_get (model, &iter,
 				    AUDIO_INFO_COLUMN, &info,
 				    -1);
-	
-		audio_view_set_playing (view, info, path);
-	}
-	else
-	{
-		message = g_strdup_printf (_("Make a selection first !"));
-		gtk_label_set_text (GTK_LABEL (view->status), message);
-		g_free (message);
 	}
+	audio_view_set_playing (view, info, path);
 }
 
 static void
